import 'package:flutter/material.dart';
import 'package:font_awesome_flutter/font_awesome_flutter.dart';
import 'package:senior_design_tokens/senior_design_tokens.dart';

class SeniorBottomSheet {
  static Future<dynamic> showBottomSheet({
    required BuildContext context,
    required double height,
    required List<Widget> content,
    required bool hasCloseButton,
    VoidCallback? onTapCloseButton,
    bool? isDismissible,
    bool? enableDrag,
  }) {
    return showModalBottomSheet(
      isDismissible: isDismissible ?? false,
      enableDrag: enableDrag ?? false,
      isScrollControlled: true,
      shape: RoundedRectangleBorder(
        borderRadius: BorderRadius.only(
          topLeft: Radius.circular(
            SeniorRadius.huge,
          ),
          topRight: Radius.circular(
            SeniorRadius.huge,
          ),
        ),
      ),
      backgroundColor: SeniorColors.pureWhite,
      context: context,
      constraints: BoxConstraints(
        maxHeight: height,
      ),
      builder: (BuildContext context) {
        return Column(
          children: [
            hasCloseButton
                ? Container(
                    margin: EdgeInsets.only(
                      right: 16.0,
                      top: 16.0,
                    ),
                    alignment: Alignment.topRight,
                    child: IconButton(
                      padding: EdgeInsets.zero,
                      icon: FaIcon(
                        FontAwesomeIcons.times,
                        size: SeniorTypographyIconSize.CTA,
                        color: SeniorColors.primaryColor300,
                      ),
                      onPressed: onTapCloseButton,
                    ),
                  )
                : SizedBox(
                    height: 24.0,
                  ),
            ...content,
          ],
        );
      },
    );
  }
}
